"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const morgan = require("morgan");
const prettyBytes = require("pretty-bytes");
const chalk_1 = require("chalk");
exports.nocache = (req, res, next) => {
    res.setHeader("Surrogate-Control", "no-store");
    res.setHeader("Cache-Control", "no-store, no-cache, must-revalidate, proxy-revalidate");
    res.setHeader("Pragma", "no-cache");
    res.setHeader("Expires", "0");
    next();
};
exports.addslash = (req, res, next) => {
    const extension = path.extname(req.path);
    if (!extension && req.path.substr(-1) !== "/") {
        const query = req.url.slice(req.path.length);
        res.redirect(301, req.path + "/" + query);
    }
    else {
        next();
    }
};
exports.logging = morgan((tokens, req, res) => {
    // Filter out all paths starting with /_ like socket.io
    if (tokens.url(req, res).startsWith("/_")) {
        return null;
    }
    let status = tokens.status(req, res);
    if (status !== "200") {
        status = chalk_1.default.red(status);
    }
    return chalk_1.default.gray([
        // _.last(remoteAddress.split(":")),
        tokens.method(req, res),
        status,
        chalk_1.default.rgb(170, 170, 170)(tokens.url(req, res)),
        prettyBytes(parseInt(tokens.res(req, res, "content-length") || "0")),
        `(${Math.round(parseFloat(tokens["response-time"](req, res)) || 0)}ms)`,
    ].join(" "));
});
exports.cors = (req, res, next) => {
    res.header("Access-Control-Allow-Origin", "*");
    res.header("Access-Control-Allow-Headers", "Origin, X-Requested-With, Content-Type, Accept, Authorization");
    next();
};
exports.isAuthenticated = (req, res, next) => {
    const { AUTHORIZATION_TOKEN: authorization } = process.env;
    if (authorization && req.headers.authorization !== `token ${authorization}`) {
        res.send(401);
    }
    else {
        next();
    }
};
